@@ -329,3 +329,9 @@ void CentralWidget::slotGameOver()
     if (settings_.startNewGame())
         newGame();
 }
+
+void CentralWidget::slotResetScore()
+{
+    score_.reset();
+    scorePanel_->setScore(0, 0, 0);
+}
