@@ -41,6 +41,10 @@ void MainWindow::createMenuToolbar()
     QAction *a = mn->addAction(tr("&New game"));
     a->setShortcut(Qt::CTRL + Qt::Key_N);
     connect(a, SIGNAL(triggered()), this, SLOT(slotNewGame()));
+
+    a = mn->addAction(tr("&Reset score"));
+    connect(a, SIGNAL(triggered()), centralWdgt, SLOT(slotResetScore()));
+
     mn->addSeparator();
 
     a = mn->addAction(tr("E&xit"));
