@@ -11,7 +11,7 @@ class ModePanel : public QWidget
     Q_OBJECT
 
 public:
-    explicit ModePanel(QWidget *parent = 0);
+    explicit ModePanel(QWidget *parent = 0, int defaultMode = 1, int defaultAILevel = 1);
     QPair<int, int>  mode() const;
 private:
     QComboBox *cbMode_;
