@@ -28,6 +28,10 @@ OptionsDialog::OptionsDialog(QthelloSettings *settings, QWidget *parent):
     chbSaveMode_->setChecked(settings_->saveMode());
     topLayout->addWidget(chbSaveMode_);
 
+    chbStartNewGame_ = new QCheckBox(tr("Start new game automatically"), this);
+    chbStartNewGame_->setChecked(settings_->startNewGame());
+    topLayout->addWidget(chbStartNewGame_);
+
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     topLayout->addWidget(buttonBox);
 
@@ -39,5 +43,6 @@ void OptionsDialog::slotOk()
 {
     settings_->setAnimationSpeed(cbAnimationSpeed_->currentIndex());
     settings_->setSaveMode(chbSaveMode_->isChecked());
+    settings_->setStartNewGame(chbStartNewGame_->isChecked());
     accept();
 }
