@@ -36,7 +36,7 @@ void ReversiGame::init(int mode, int strength, bool isNetworkGame)
     else if (mode_ == 1)
         computerColor_ = White;
     
-    emit newGame(isNetworkGame);
+    emit newGame(mode);
     startNextTurn();
 }//init
 
